Learn R Programming

BaHZING (version 1.0.0)

iHMP_Reduced: iHMP_Reduced data

Description

A subset of data from the Integrative Human Microbiome Project

Usage

iHMP_Reduced

Arguments

Format

iHMP_Reduced

A phyloseq object with subset microbiome data for 105 participants at their first visit.